==> antd-mobile-0.9.14.tgz: package/lib/image-picker/index.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');
var _style=require('./style/');var _style2=_interopRequireDefault(_style);
var _ImageRoll=require('./ImageRoll');var _ImageRoll2=_interopRequireDefault(_ImageRoll);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var
ImagePicker=function(_React$Component){(0,_inherits3["default"])(ImagePicker,_React$Component);
function ImagePicker(props){(0,_classCallCheck3["default"])(this,ImagePicker);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.call(this,props));
_this.onPressIn=function(){
var styles=_this.props.styles;
_this.plusWrap.setNativeProps({
style:[styles.item,styles.size,styles.plusWrapHighlight]});

};
_this.onPressOut=function(){
var styles=_this.props.styles;
_this.plusWrap.setNativeProps({
style:[styles.item,styles.size,styles.plusWrapNormal]});

};















_this.showPicker=function(){



















_this.setState({
visible:true});


};
_this.hideImageRoll=function(){
_this.setState({
visible:false});

};
_this.state={
visible:false};return _this;

}ImagePicker.prototype.
addImage=function addImage(imageObj){
if(!imageObj.url){
imageObj.url=imageObj.uri;
delete imageObj.uri;
}var _props$files=
this.props.files,files=_props$files===undefined?[]:_props$files;
var newImages=files.concat(imageObj);
if(this.props.onChange){
this.props.onChange(newImages,'add');
}
};ImagePicker.prototype.
removeImage=function removeImage(idx){
var newImages=[];var _props$files2=
this.props.files,files=_props$files2===undefined?[]:_props$files2;
files.forEach(function(image,index){
if(index!==idx){
newImages.push(image);
}
});
if(this.props.onChange){
this.props.onChange(newImages,'remove',idx);
}
};ImagePicker.prototype.
render=function render(){var _this2=this;var _props=
this.props,styles=_props.styles,_props$files3=_props.files,files=_props$files3===undefined?[]:_props$files3;
return _react2["default"].createElement(_reactNative.View,{style:styles.container},
files.map(function(item,index){return _react2["default"].createElement(_reactNative.View,{key:index,style:[styles.item,styles.size]},
_react2["default"].createElement(_reactNative.Image,{source:{uri:item.url},style:[styles.size,styles.image]}),
_react2["default"].createElement(_reactNative.TouchableWithoutFeedback,{onPress:function onPress(){return _this2.removeImage(index);}},
_react2["default"].createElement(_reactNative.View,{style:styles.closeWrap},
_react2["default"].createElement(_reactNative.Text,{style:styles.closeText},"×"))));}),


_react2["default"].createElement(_reactNative.TouchableWithoutFeedback,{onPress:this.showPicker,onPressIn:this.onPressIn,onPressOut:this.onPressOut},
_react2["default"].createElement(_reactNative.View,{ref:function ref(conponent){return _this2.plusWrap=conponent;},style:[styles.item,styles.size,styles.plusWrap,styles.plusWrapNormal]},
_react2["default"].createElement(_reactNative.Text,{style:[styles.plusNormal,styles.plusText]},"+"))),


this.state.visible?_react2["default"].createElement(_ImageRoll2["default"],{onCancel:this.hideImageRoll,onSelected:function onSelected(imgObj){return _this2.addImage(imgObj);}}):null);
};return ImagePicker;}(_react2["default"].Component);exports["default"]=ImagePicker;

ImagePicker.defaultProps={
styles:_style2["default"],
onChange:function onChange(){},
files:[]};module.exports=exports['default'];

==> antd-mobile-1.0.1.tgz: package/lib/image-picker/index.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');


var _style=require('./style/');var _style2=_interopRequireDefault(_style);
var _ImageRoll=require('./ImageRoll');var _ImageRoll2=_interopRequireDefault(_ImageRoll);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var
ImagePicker=function(_React$Component){(0,_inherits3["default"])(ImagePicker,_React$Component);
function ImagePicker(props){(0,_classCallCheck3["default"])(this,ImagePicker);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.call(this,props));
_this.onPressIn=function(){
var styles=_this.props.styles;
_this.plusWrap.setNativeProps({
style:[styles.item,styles.size,styles.plusWrapHighlight]});

};
_this.onPressOut=function(){
var styles=_this.props.styles;
_this.plusWrap.setNativeProps({
style:[styles.item,styles.size,styles.plusWrapNormal]});

};















_this.showPicker=function(){



















_this.setState({
visible:true});


};
_this.hideImageRoll=function(){
_this.setState({
visible:false});

};
_this.state={
visible:false};return _this;

}ImagePicker.prototype.
addImage=function addImage(imageObj){
if(!imageObj.url){
imageObj.url=imageObj.uri;
delete imageObj.uri;
}var _props$files=
this.props.files,files=_props$files===undefined?[]:_props$files;
var newImages=files.concat(imageObj);
if(this.props.onChange){
this.props.onChange(newImages,'add');
}
};ImagePicker.prototype.
removeImage=function removeImage(idx){
var newImages=[];var _props$files2=
this.props.files,files=_props$files2===undefined?[]:_props$files2;
files.forEach(function(image,index){
if(index!==idx){
newImages.push(image);
}
});
if(this.props.onChange){
this.props.onChange(newImages,'remove',idx);
}
};ImagePicker.prototype.
render=function render(){var _this2=this;var _props=
this.props,styles=_props.styles,_props$files3=_props.files,files=_props$files3===undefined?[]:_props$files3;
var filesView=files.map(function(item,index){return _react2["default"].createElement(_reactNative.View,{key:index,style:[styles.item,styles.size]},
_react2["default"].createElement(_reactNative.Image,{source:{uri:item.url},style:[styles.size,styles.image]}),
_react2["default"].createElement(_reactNative.TouchableWithoutFeedback,{onPress:function onPress(){return _this2.removeImage(index);}},
_react2["default"].createElement(_reactNative.View,{style:styles.closeWrap},
_react2["default"].createElement(_reactNative.Text,{style:styles.closeText},'\xD7'))));});



var imageRollEl=_react2["default"].createElement(_ImageRoll2["default"],{onCancel:this.hideImageRoll,onSelected:function onSelected(imgObj){return _this2.addImage(imgObj);}});
return _react2["default"].createElement(_reactNative.View,{style:styles.container},
filesView,
_react2["default"].createElement(_reactNative.TouchableWithoutFeedback,{onPress:this.showPicker,onPressIn:this.onPressIn,onPressOut:this.onPressOut},
_react2["default"].createElement(_reactNative.View,{ref:function ref(conponent){return _this2.plusWrap=conponent;},style:[styles.item,styles.size,styles.plusWrap,styles.plusWrapNormal]},
_react2["default"].createElement(_reactNative.Text,{style:[styles.plusNormal,styles.plusText]},'+'))),


this.state.visible?imageRollEl:null);

};return ImagePicker;}(_react2["default"].Component);exports["default"]=ImagePicker;

ImagePicker.defaultProps={
styles:_style2["default"],
onChange:function onChange(){},
files:[]};module.exports=exports['default'];
